@@ -2,10 +2,9 @@ from __future__ import annotations
 
 import re
 import sys
-from typing import TypedDict
+from typing import TYPE_CHECKING, TypedDict
 
 from commitizen import factory, git, out
-from commitizen.config import BaseConfig
 from commitizen.exceptions import (
     CommitMessageLengthExceededError,
     InvalidCommandArgumentError,
@@ -13,6 +12,9 @@ from commitizen.exceptions import (
     NoCommitsFoundError,
 )
 
+if TYPE_CHECKING:
+    from commitizen.config import BaseConfig
+
 
 class CheckArgs(TypedDict, total=False):
     commit_msg_file: str
