@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Generator
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from commitizen import defaults, git
 from commitizen.config.factory import create_config
@@ -9,6 +9,9 @@ from commitizen.exceptions import ConfigFileIsEmpty, ConfigFileNotFound
 
 from .base_config import BaseConfig
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+
 
 def _resolve_config_paths(filepath: str | None = None) -> Generator[Path, None, None]:
     if filepath is not None:
