@@ -5,17 +5,14 @@ import re
 import sys
 from pathlib import Path
 from textwrap import dedent
+from typing import TYPE_CHECKING
 from unittest.mock import MagicMock, call
 
-import py
 import pytest
-from pytest_mock import MockFixture
 
 import commitizen.commands.bump as bump
 from commitizen import cli, cmd, defaults, git, hooks
-from commitizen.changelog_formats import ChangelogFormat
 from commitizen.config.base_config import BaseConfig
-from commitizen.cz.base import BaseCommitizen
 from commitizen.exceptions import (
     BumpTagFailedError,
     CommitizenException,
@@ -23,7 +20,6 @@ from commitizen.exceptions import (
     DryRunExit,
     ExitCode,
     ExpectedExit,
-    GetNextExit,
     InvalidManualVersion,
     NoCommitsFoundError,
     NoneIncrementExit,
@@ -34,6 +30,13 @@ from commitizen.exceptions import (
 )
 from tests.utils import create_file_and_commit, create_tag, skip_below_py_3_13
 
+if TYPE_CHECKING:
+    import py
+    from pytest_mock import MockFixture
+
+    from commitizen.changelog_formats import ChangelogFormat
+    from commitizen.cz.base import BaseCommitizen
+
 
 @pytest.mark.parametrize(
     "commit_msg",
@@ -647,13 +650,11 @@ def test_none_increment_should_not_call_git_tag_and_error_code_is_not_zero(
     dummy_value = git.tag("0.0.2")
     git.tag = MagicMock(return_value=dummy_value)
 
-    with pytest.raises(NoneIncrementExit):
-        try:
-            cli.main()
-        except NoneIncrementExit as e:
-            git.tag.assert_not_called()
-            assert e.exit_code == ExitCode.NO_INCREMENT
-            raise e
+    with pytest.raises(NoneIncrementExit) as e:
+        cli.main()
+
+    git.tag.assert_not_called()
+    assert e.value.exit_code == ExitCode.NO_INCREMENT
 
     # restore pop stashed
     git.tag = stashed_git_tag
@@ -1456,7 +1457,7 @@ def test_bump_get_next(mocker: MockFixture, capsys):
 
     testargs = ["cz", "bump", "--yes", "--get-next"]
     mocker.patch.object(sys, "argv", testargs)
-    with pytest.raises(GetNextExit):
+    with pytest.raises(DryRunExit):
         cli.main()
 
     out, _ = capsys.readouterr()
@@ -1476,7 +1477,7 @@ def test_bump_get_next_update_changelog_on_bump(
 
     testargs = ["cz", "bump", "--yes", "--get-next"]
     mocker.patch.object(sys, "argv", testargs)
-    with pytest.raises(GetNextExit):
+    with pytest.raises(DryRunExit):
         cli.main()
 
     out, _ = capsys.readouterr()
@@ -1486,39 +1487,6 @@ def test_bump_get_next_update_changelog_on_bump(
     assert tag_exists is False
 
 
-@pytest.mark.usefixtures("tmp_commitizen_project")
-def test_bump_get_next__changelog_is_not_allowed(mocker: MockFixture):
-    create_file_and_commit("feat: new file")
-
-    testargs = ["cz", "bump", "--yes", "--get-next", "--changelog"]
-    mocker.patch.object(sys, "argv", testargs)
-
-    with pytest.raises(NotAllowed):
-        cli.main()
-
-
-@pytest.mark.usefixtures("tmp_commitizen_project")
-def test_bump_get_next__changelog_to_stdout_is_not_allowed(mocker: MockFixture):
-    create_file_and_commit("feat: new file")
-
-    testargs = ["cz", "bump", "--yes", "--get-next", "--changelog-to-stdout"]
-    mocker.patch.object(sys, "argv", testargs)
-
-    with pytest.raises(NotAllowed):
-        cli.main()
-
-
-@pytest.mark.usefixtures("tmp_commitizen_project")
-def test_bump_get_next__manual_version_is_not_allowed(mocker: MockFixture):
-    create_file_and_commit("feat: new file")
-
-    testargs = ["cz", "bump", "--yes", "--get-next", "0.2.1"]
-    mocker.patch.object(sys, "argv", testargs)
-
-    with pytest.raises(NotAllowed):
-        cli.main()
-
-
 @pytest.mark.usefixtures("tmp_commitizen_project")
 def test_bump_get_next__no_eligible_commits_raises(mocker: MockFixture):
     create_file_and_commit("chore: new commit")
