@@ -1,14 +1,18 @@
 from __future__ import annotations
 
-from pathlib import Path
 from textwrap import dedent
+from typing import TYPE_CHECKING
 
 import pytest
 
-from commitizen.config.base_config import BaseConfig
 from commitizen.providers import get_provider
 from commitizen.providers.pep621_provider import Pep621Provider
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from commitizen.config.base_config import BaseConfig
+
 PEP621_TOML = """\
 [project]
 version = "0.1.0"
